@@ -5,7 +5,7 @@ use overload;
 
 
 # version
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 
 #------------------------------------------------------------------------------
@@ -59,10 +59,10 @@ String::Util -- String processing utilities
   $val = randcrypt($val);
 
   # are these two values equal, where two undefs count as "equal"?
-  if (equndef $a, $b) {...}
+  if (eqq $a, $b) {...}
 
   # are these two values different, where two undefs count as "equal"?
-  if (neundef $a, $b) {...}
+  if (neqq $a, $b) {...}
 
   # get a random string of some specified length
   $val = randword(10);
@@ -91,7 +91,6 @@ String::Util can be installed with the usual routine:
 
 
 
-
 #------------------------------------------------------------------------------
 # export
 #
@@ -101,13 +100,14 @@ use vars qw[@EXPORT_OK %EXPORT_TAGS];
 # the following functions accept a value and return a modified version of
 # that value
 push @EXPORT_OK, qw[
-	crunch     htmlesc    trim      ltrim      rtrim
-	define     repeat     unquote   no_space   nospace
-	fullchomp  randcrypt  jsquote   cellfill   crunchlines
+	collapse     crunch     htmlesc    trim      ltrim
+	rtrim        define     repeat     unquote   no_space
+	nospace      fullchomp  randcrypt  jsquote   cellfill
+	crunchlines  spacepad
 ];
 
 # the following functions return true or false based on their input
-push @EXPORT_OK, qw[ hascontent nocontent equndef neundef ];
+push @EXPORT_OK, qw[ hascontent nocontent eqq equndef neqq neundef ];
 
 # the following function returns a random string of some type
 push @EXPORT_OK, qw[ randword randpost ];
@@ -125,14 +125,20 @@ push @EXPORT_OK, qw[ ords deords ];
 # crunch
 #
 
-=head2 crunch(string)
+=head2 collapse(string), crunch(string)
 
-Crunches all whitespace in the string down to single spaces.  Also removes all
-leading and trailing whitespace.  Undefined input results in undefined output.
+C<collapse()> collapses all whitespace in the string down to single spaces.
+Also removes all leading and trailing whitespace.  Undefined input results in
+undefined output.
+
+C<crunch()> is the old name for C<collapse()>. I decided that "crunch" never
+sounded right. Spaces don't go "crunch", they go "poof" like a collapsing
+ballon. However, C<crunch()> will continue to work as an alias for
+C<collapse()>.
 
 =cut
 
-sub crunch {
+sub collapse {
 	my ($val) = @_;
 	
 	if (defined $val) {
@@ -143,6 +149,10 @@ sub crunch {
 	
 	return $val;
 }
+
+sub crunch {
+	return collapse(@_);
+}
 #
 # crunch
 #------------------------------------------------------------------------------
@@ -158,9 +168,9 @@ hascontent() returns true if the given argument is defined and contains
 something besides whitespace.
 
 An undefined value returns false.  An empty string returns false.  A value
-containing nothing but whitespace (spaces, tabs, carriage returns,
-newlines, backspace) returns false.  A string containing any other
-characers (including zero) returns true.
+containing nothing but whitespace (spaces, tabs, carriage returns, newlines,
+backspace) returns false.  A string containing any other characters (including
+zero) returns true.
 
 C<nocontent()> returns the negation of C<hascontent()>.
 
@@ -295,13 +305,12 @@ sub nospace { return no_space(@_) }
 
 =head2 htmlesc(string)
 
-Formats a string for literal output in HTML.  An undefined value is
-returned as an empty string.
+Formats a string for literal output in HTML.  An undefined value is returned as
+an empty string.
 
-htmlesc is very similar to CGI.pm's escapeHTML.  If your script already loads
-CGI.pm, you may well not need htmlesc.  However, there are a few differences.
-htmlesc> changes an undefined value to an empty string, whereas escapeHTML
-returns undefs as undefs.
+htmlesc() is very similar to CGI.pm's escapeHTML.  However, there are a few
+differences. htmlesc() changes an undefined value to an empty string, whereas
+escapeHTML() returns undefs as undefs.
 
 =cut
 
@@ -332,8 +341,8 @@ sub htmlesc{
 =head2 cellfill(string)
 
 Formats a string for literal output in an HTML table cell.  Works just like
-htmlesc except that strings with no content (i.e. are undef or are just
-whitespace) are returns as C<&nbsp;>.
+htmlesc() except that strings with no content (i.e. are undef or are just
+whitespace) are returned as C<&nbsp;>.
 
 =cut
 
@@ -397,15 +406,25 @@ sub jsquote {
 
 =head2 unquote(string)
 
-If the given string starts and ends with quotes, removes them.
-Recognizes single quotes and double quotes.  The value must begin
-and end with same type of quotes or nothing is done to the value.
-Undef input results in undef output.
+If the given string starts and ends with quotes, removes them. Recognizes
+single quotes and double quotes.  The value must begin and end with same type
+of quotes or nothing is done to the value. Undef input results in undef output.
+Some examples and what they return:
+
+ unquote(q|'Hendrix'|);   # Hendrix
+ unquote(q|"Hendrix"|);   # Hendrix
+ unquote(q|Hendrix|);     # Hendrix
+ unquote(q|"Hendrix'|);   # "Hendrix'
+ unquote(q|O'Sullivan|);  # O'Sullivan
 
 B<option:> braces
 
 If the braces option is true, surrounding braces such as [] and {} are also
-removed.
+removed. Some examples:
+
+ unquote(q|[Janis]|, braces=>1);  # Janis
+ unquote(q|{Janis}|, braces=>1);  # Janis
+ unquote(q|(Janis)|, braces=>1);  # Janis
 
 =cut
 
@@ -414,11 +433,12 @@ sub unquote {
 	
 	if (defined $val) {
 		my $found = $val =~ s|^\`(.*)\`$|$1|s or
-		$val =~ s|^\"(.*)\"$|$1|s or
-		$val =~ s|^\'(.*)\'$|$1|s;
+			$val =~ s|^\"(.*)\"$|$1|s or
+			$val =~ s|^\'(.*)\'$|$1|s;
 		
 		if ($opts{'braces'} && ! $found) {
 			$val =~ s|^\[(.*)\]$|$1|s or
+			$val =~ s|^\((.*)\)$|$1|s or
 			$val =~ s|^\{(.*)\}$|$1|s;
 		}
 	}
@@ -440,9 +460,10 @@ Takes a single value as input. If the value is defined, it is returned
 unchanged.  If it is not defined, an empty string is returned.
 
 This subroutine is useful for printing when an undef should simply be
-represented as an empty string.  Granted, Perl already treats undefs as
-empty strings in string context, but this sub makes -w happy.  And you
-B<ARE> using -w, right?
+represented as an empty string.  Perl already treats undefs as empty strings in
+string context, but this subroutine makes the
+L<warnings module|http://perldoc.perl.org/warnings.html>
+go away.  And you B<ARE> using warnings, right?
 
 =cut
 
@@ -470,7 +491,18 @@ sub define {
 
 =head2 repeat($string, $count)
 
-Returns the given string repeated the given number of times.
+Returns the given string repeated the given number of times. The following
+command outputs "Fred" three times:
+
+ print repeat('Fred', 3), "\n";
+
+Note that repeat() was created a long time based on a misunderstanding of how
+the perl operator 'x' works.  The following command using 'x' would perform
+exactly the same as the above command.
+
+ print 'Fred' x 3, "\n";
+
+Use whichever you prefer.
 
 =cut
 
@@ -491,28 +523,79 @@ sub repeat {
 
 Returns a random string of characters. String will not contain any vowels (to
 avoid distracting dirty words). First argument is the length of the return
-string.
+string. So this code:
+
+ foreach my $idx (1..3) {
+   print randword(4), "\n";
+ }
+
+would output something like this:
+
+ kBGV
+ NCWB
+ 3tHJ
 
 If the string 'dictionary' is sent instead of an integer, then a word is
 randomly selected from a dictionary file.  By default, the dictionary file
 is assumed to be at /usr/share/dict/words and the shuf command is used to
 pull out a word.  The hash %String::Util::PATHS sets the paths to the
 dictionary file and the shuf executable.  Modify that hash to change the paths.
+So this code:
+
+ foreach my $idx (1..3) {
+   print randword('dictionary'), "\n";
+ }
+
+would output something like this:
+
+ mustache
+ fronds
+ browning
 
 B<option:> alpha
 
 If the alpha option is true, only alphabetic characters are returned, no
-numerals.
+numerals. For example, this code:
+
+ foreach my $idx (1..3) {
+   print randword(4, alpha=>1), "\n";
+ }
+
+would output something like this:
+
+ qrML
+ wmWf
+ QGvF
 
 B<option:> numerals
 
 If the numerals option is true, only numerals are returned, no alphabetic
-characters.
+characters. So this code:
+
+ foreach my $idx (1..3) {
+   print randword(4, numerals=>1), "\n";
+ }
+
+would output something like this:
+
+ 3981
+ 4734
+ 2657
 
 B<option:> strip_vowels
 
 This option is true by default.  If true, vowels are not included in the
-returned random string.
+returned random string. So this code:
+
+ foreach my $idx (1..3) {
+   print randword(4, strip_vowels=>1), "\n";
+  }
+
+would output something like this:
+
+ Sk3v
+ pV5z
+ XhSX
 
 =cut
 
@@ -623,51 +706,85 @@ sub randword {
 
 
 #------------------------------------------------------------------------------
-# equndef
+# eqq
+# formerly equndef
 #
 
-=head2 equndef($str1, $str2)
+=head2 eqq($val1, $val2)
 
-Returns true if the two given strings are equal.  Also returns true if both
+Returns true if the two given values are equal.  Also returns true if both
 are undef.  If only one is undef, or if they are both defined but different,
-returns false.
+returns false. Here are some examples and what they return.
+
+ eqq('x', 'x'), "\n";      # 1
+ eqq('x', undef), "\n";    # 0
+ eqq(undef, undef), "\n";  # 1
 
 =cut
 
-sub equndef {
+# alias equndef to eqq
+sub equndef { return eqq(@_) }
+
+sub eqq {
 	my ($str1, $str2) = @_;
 	
 	# if both defined
 	if ( defined($str1) && defined($str2) )
-		{return $str1 eq $str2}
+		{ return $str1 eq $str2 }
 	
 	# if neither are defined 
 	if ( (! defined($str1)) && (! defined($str2)) )
-		{return 1}
+		{ return 1 }
 	
 	# only one is defined, so return false
 	return 0;
 }
 #
-# equndef
+# eqq
 #------------------------------------------------------------------------------
 
 
 #------------------------------------------------------------------------------
-# neundef
+# neqq
+# formerly neundef
 #
 
-=head2 neundef($str1, $str2)
+=head2 neqq($str1, $str2)
 
-The opposite of equndef, returns true if the two strings are *not* the same.
+The opposite of neqq, returns true if the two values are *not* the same.
+Here are some examples and what they return.
+
+ print neqq('x', 'x'), "\n";      # 0
+ print neqq('x', undef), "\n";    # 1
+ print neqq(undef, undef), "\n";  # 0
 
 =cut
 
 sub neundef {
-	return equndef(@_) ? 0 : 1;
+	return eqq(@_) ? 0 : 1;
+}
+
+sub neqq {
+	return eqq(@_) ? 0 : 1;
 }
 #
-# neundef
+# neqq
+#------------------------------------------------------------------------------
+
+
+#------------------------------------------------------------------------------
+# pod to note renaming of equndef to eqq and neundef to neqq
+#
+
+=head2 equndef(), neundef()
+
+equndef() has been renamed to eqq(). neundef() has been renamed to neqq().
+Those old names have been kept as aliases.
+
+=cut
+
+#
+# pod to note renaming of equndef to eqq and neundef to neqq
 #------------------------------------------------------------------------------
 
 
@@ -701,8 +818,8 @@ sub fullchomp {
 
 =head2 randcrypt(string)
 
-Crypts the given string, seeding the encryption with a random
-two character seed.
+Crypts the given string, seeding the encryption with a random two character
+seed.
 
 =cut
 
@@ -733,13 +850,12 @@ Sets how many words should be in the post.  By default a random number from
 
 B<option:> par_odds
 
-Sets the odds of starting a new paragraph after any given word.  By default
-the value is .05, which means paragraphs will have an average about twenty
-words.
+Sets the odds of starting a new paragraph after any given word.  By default the
+value is .05, which means paragraphs will have an average about twenty words.
 
 B<option:> par
 
-Sets the string to put at the end or the start and end of a paragraph.
+Sets the string to put at the end or the start and end of a paragraph. 
 Defaults to two newlines for the end of a pargraph.
 
 If this option is a single scalar, that string is added to the end of each
@@ -751,8 +867,7 @@ should be the string to put at the end of a paragraph.
 
 B<option:> max_length
 
-Sets the maximum length of the returned string, including paragraph
-delimiters.
+Sets the maximum length of the returned string, including paragraph delimiters.
 
 =cut
 
@@ -900,7 +1015,6 @@ returns this:
 
  a{61}b
 
-
 =back
 
 =cut
@@ -997,8 +1111,8 @@ sub deords {
 =head2 crunchlines($str)
 
 Compacts contiguous newlines into single newlines.  Whitespace between newlines
-is ignored, so that two newlines separated by whitespace is compacted down to
-a single newline.
+is ignored, so that two newlines separated by whitespace is compacted down to a
+single newline.
 
 For example, this code:
 
@@ -1029,6 +1143,30 @@ sub crunchlines {
 
 
 
+#------------------------------------------------------------------------------
+# spacepad
+#
+
+=head2 spacepad
+
+=cut
+
+sub spacepad {
+	my ($str, $length) = @_;
+	
+	# add spaces
+	while (length($str) < $length) {
+		$str .= ' ';
+	}
+	
+	# return
+	return $str;
+}
+#
+# spacepad
+#------------------------------------------------------------------------------
+
+
 # return true
 1;
 
@@ -1037,8 +1175,8 @@ __END__
 
 =head1 TERMS AND CONDITIONS
 
-Copyright (c) 2012 by Miko O'Sullivan.  All rights reserved.  This program is 
-free software; you can redistribute it and/or modify it under the same terms 
+Copyright (c) 2012-2016 by Miko O'Sullivan.  All rights reserved.  This program
+is free software; you can redistribute it and/or modify it under the same terms
 as Perl itself. This software comes with B<NO WARRANTY> of any kind.
 
 =head1 AUTHORS
@@ -1075,15 +1213,15 @@ Properly listing prerequisites.
 
 =item Version 1.21, July 18, 2012
 
-Fixed error in POD.  Tightened up code for repet.
+Fixed error in POD.
 
-=item Version 1.22
+=item Version 1.22, July 20, 2012
 
 Fix in documentation for randpost().
 
 Clarified documentation for hascontent() and nocontent().
 
-=item Version 1.23
+=item Version 1.23, Sep 1, 2012
 
 Fixed error in META.yml.
 
@@ -1096,7 +1234,36 @@ it was using Windowish newline. How embarrasing.
 
 Added some features to ords().
 
+=item Version 1.25, January 4, 2015
+
+Added parentheses to braces option for unquote. Cleaned up and added to POD.
+Minor fixes to comments.
+
+Renamed equndef to eqq, and neundef to neqq. However, the old names have been
+kept as aliases.
+
+Minor cleanup of formatting.
+
 =back
 
 
 =cut
+
+
+
+#------------------------------------------------------------------------------
+# module info
+# This info is used by a home-grown CPAN builder. Please leave it as it is.
+#
+{
+	// include in CPAN distribution
+	include : 1,
+	
+	// test scripts
+	test_scripts : {
+		'Util/tests/test.pl' : 1,
+	},
+}
+#
+# module info
+#------------------------------------------------------------------------------
